==> jc-1.4.0.tar.gz: gnu/xml/transform/CurrentFunction.h <==
// final class gnu.xml.transform.CurrentFunction

// class file dependencies
// @dep_class deaa9cc9d161b5d6 gnu_xml_transform_CurrentFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_CurrentFunction_H_
#define _JC_gnu_xml_transform_CurrentFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_CurrentFunction$sub_refs	_jc_gnu_xml_transform_CurrentFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_CurrentFunction$sub_nonrefs	_jc_gnu_xml_transform_CurrentFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_CurrentFunction$refs	_jc_gnu_xml_transform_CurrentFunction$refs;
typedef struct _jc_gnu_xml_transform_CurrentFunction$nonrefs	_jc_gnu_xml_transform_CurrentFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_CurrentFunction$object	_jc_gnu_xml_transform_CurrentFunction$object;

typedef const struct _jc_gnu_xml_transform_CurrentFunction$vmethods	_jc_gnu_xml_transform_CurrentFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_CurrentFunction$vtable	_jc_gnu_xml_transform_CurrentFunction$vtable;
typedef const struct _jc_gnu_xml_transform_CurrentFunction$vtype	_jc_gnu_xml_transform_CurrentFunction$vtype;

// Constructors
extern void _jc_gnu_xml_transform_CurrentFunction$method$_init$12c4ddb4b942002a(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_CurrentFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_CurrentFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_CurrentFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *, jint, jint);
extern void _jc_gnu_xml_transform_CurrentFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_CurrentFunction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$setArguments$09123773dfa6e512;
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_transform_CurrentFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *, jint, jint);
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *);
};

// Vtable
struct _jc_gnu_xml_transform_CurrentFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_CurrentFunction$vmethods	gnu_xml_transform_CurrentFunction;
};

// Vtype
struct _jc_gnu_xml_transform_CurrentFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_CurrentFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_CurrentFunction$sub_refs {
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_CurrentFunction$refs {
    _jc_gnu_xml_transform_CurrentFunction$sub_refs	gnu_xml_transform_CurrentFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_CurrentFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_CurrentFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_CurrentFunction$sub_nonrefs	gnu_xml_transform_CurrentFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_CurrentFunction$object {
	_jc_gnu_xml_transform_CurrentFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_CurrentFunction$vtype	*vtype;
	_jc_gnu_xml_transform_CurrentFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_CurrentFunction$vtype _jc_gnu_xml_transform_CurrentFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_CurrentFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_CurrentFunction$class_object;

#endif	/* _JC_gnu_xml_transform_CurrentFunction_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/CurrentFunction.h <==
// final class gnu.xml.transform.CurrentFunction

// class file dependencies
// @dep_class deaa9cc9d161b5d6 gnu_xml_transform_CurrentFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_CurrentFunction_H_
#define _JC_gnu_xml_transform_CurrentFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_CurrentFunction$sub_refs	_jc_gnu_xml_transform_CurrentFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_CurrentFunction$sub_nonrefs	_jc_gnu_xml_transform_CurrentFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_CurrentFunction$refs	_jc_gnu_xml_transform_CurrentFunction$refs;
typedef struct _jc_gnu_xml_transform_CurrentFunction$nonrefs	_jc_gnu_xml_transform_CurrentFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_CurrentFunction$object	_jc_gnu_xml_transform_CurrentFunction$object;

typedef const struct _jc_gnu_xml_transform_CurrentFunction$vmethods	_jc_gnu_xml_transform_CurrentFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_CurrentFunction$vtable	_jc_gnu_xml_transform_CurrentFunction$vtable;
typedef const struct _jc_gnu_xml_transform_CurrentFunction$vtype	_jc_gnu_xml_transform_CurrentFunction$vtype;

// Constructors
extern void _jc_gnu_xml_transform_CurrentFunction$method$_init$12c4ddb4b942002a(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_CurrentFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_CurrentFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_CurrentFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_CurrentFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_CurrentFunction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$setArguments$09123773dfa6e512;
extern _jc_method _jc_gnu_xml_transform_CurrentFunction$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_transform_CurrentFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_transform_CurrentFunction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_CurrentFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_CurrentFunction$vmethods	gnu_xml_transform_CurrentFunction;
};

// Vtype
struct _jc_gnu_xml_transform_CurrentFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_CurrentFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_CurrentFunction$sub_refs {
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_CurrentFunction$refs {
    _jc_gnu_xml_transform_CurrentFunction$sub_refs	gnu_xml_transform_CurrentFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_CurrentFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_CurrentFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_CurrentFunction$sub_nonrefs	gnu_xml_transform_CurrentFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_CurrentFunction$object {
	_jc_gnu_xml_transform_CurrentFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_CurrentFunction$vtype	*vtype;
	_jc_gnu_xml_transform_CurrentFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_CurrentFunction$vtype _jc_gnu_xml_transform_CurrentFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_CurrentFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_CurrentFunction$class_object;

#endif	/* _JC_gnu_xml_transform_CurrentFunction_H_ */
